@@ -138,11 +138,12 @@ public abstract class AbstractConnector<T> implements Connector<T, T> {
         try {
             StatusLine statusLine = response.getStatusLine();
             int statusCode = statusLine.getStatusCode();
-            HttpEntity entity = new BufferedHttpEntity(response.getEntity());
+            HttpEntity entity = response.getEntity();
             ObjectMapper mapper = JacksonUtil.getMapper();
             T responseBody;
             JavaType responseBodyType = getResponseBodyType(mapper);
             if (log.isDebugEnabled()) {
+                entity = new BufferedHttpEntity(response.getEntity());
                 ByteArrayOutputStream baos = new ByteArrayOutputStream();
                 entity.writeTo(baos);
                 log.debug(new String(baos.toByteArray(), "UTF-8"));
