@@ -83,7 +83,7 @@ public interface ConnectorFactory {
 
     AccountsConnector getAccountsConnector(SessionData sessionData);
 
-    AllFoldersConnector getAllFoldersConnector(SessionData sessionData, String language);
+    AllFoldersConnector getAllFoldersConnector(SessionData sessionData, String rootFolderId, String language);
 
     ClearFolderConnector getClearFolderConnector(SessionData sessionData, String folderId);
 
