@@ -75,8 +75,8 @@ public class DefaultConnectorFactory implements ConnectorFactory {
     }
 
     @Override
-    public AllFoldersConnector getAllFoldersConnector(SessionData sessionData, String language) {
-        return new AllFoldersConnector(configuration, sessionData, language);
+    public AllFoldersConnector getAllFoldersConnector(SessionData sessionData, String rootFolderId, String language) {
+        return new AllFoldersConnector(configuration, sessionData, rootFolderId, language);
     }
 
     @Override
