@@ -49,6 +49,8 @@
 
 package com.openexchange.mobile.api.facade.endpoints;
 
+import java.util.regex.Pattern;
+
 import javax.annotation.security.PermitAll;
 import javax.servlet.http.HttpServletRequest;
 import javax.ws.rs.Consumes;
@@ -82,6 +84,8 @@ import lombok.extern.slf4j.Slf4j;
 @Slf4j
 public class AuthenticationEndpoint {
 
+    private static final Pattern PATTERN_CLIENT_ID = Pattern.compile("^\\p{Alnum}*$");
+
     private final MultipleAuthenticationServicesHandler authenticationHandler;
 
     @POST
@@ -91,6 +95,7 @@ public class AuthenticationEndpoint {
     public Response authenticate(@Context HttpServletRequest request, String rawRequestBody) {
         log.info("Authenticating client");
         AuthenticationRequestBody authenticationRequestBody = JacksonUtil.parse(rawRequestBody, AuthenticationRequestBody.class);
+        validate(authenticationRequestBody);
         String userAgent = RequestUtil.getUserAgent(request);
         HostConfiguration configuration = ConfigurationHelper.getConfiguration(request);
         RequestUtil.checkUserAgent(userAgent, configuration);
@@ -102,16 +107,27 @@ public class AuthenticationEndpoint {
         return buildResponse(sessionData);
     }
 
+    void validate(AuthenticationRequestBody authenticationRequestBody) {
+        if (authenticationRequestBody == null) {
+            throw ApiFacadeException.badRequest(ApiFacadeException.Code.INTERNAL_SERVER_ERROR, "Request body missing");
+        }
+        String clientId = authenticationRequestBody.getClientId();
+        if (clientId != null && !PATTERN_CLIENT_ID.matcher(clientId).matches()) {
+            throw ApiFacadeException.badRequest(ApiFacadeException.Code.INTERNAL_SERVER_ERROR, "Invalid client ID");
+        }
+    }
+
     private LoginCredentials getCredentials(AuthenticationRequestBody requestBody) {
         String username = requestBody.getUsername();
         String password = requestBody.getPassword();
+        String clientId = requestBody.getClientId();
         if (StringUtils.isEmpty(username)) {
             throw ApiFacadeException.missingParameter("username");
         }
         if (StringUtils.isEmpty(password)) {
             throw ApiFacadeException.missingParameter("password");
         }
-        return new LoginCredentials(username, password);
+        return new LoginCredentials(username, password, clientId);
     }
 
     @POST
