@@ -75,6 +75,7 @@ import com.openexchange.mobile.api.facade.models.Mail;
 import com.openexchange.mobile.api.facade.models.MailFlags;
 import com.openexchange.mobile.api.facade.models.MailIds;
 import com.openexchange.mobile.api.facade.models.MailThread;
+import com.openexchange.mobile.api.facade.utils.AttachmentUtil;
 import com.openexchange.mobile.api.facade.utils.ListUtil;
 import com.openexchange.mobile.api.facade.utils.MailTransformations;
 import com.openexchange.mobile.api.facade.utils.MailUtil;
@@ -158,7 +159,9 @@ public class MailsService {
         MailResponseMto responseBody = connector.execute();
         Mail mail = GetMailConnector.map(responseBody.getData());
         boolean mailTeasersEnabled = sessionData.getConfiguration().isMailTeasersEnabled();
-        return MailTransformations.apply(mail, mailTeasersEnabled, maximumTeaserLength);
+        mail = MailTransformations.apply(mail, mailTeasersEnabled, maximumTeaserLength);
+        AttachmentUtil.initializeDownloadUrls(sessionData.getSession(), folderId, mail);
+        return mail;
     }
 
     public DeletedMails delete(SessionData sessionData, String folderId, List<String> mailIds, boolean purge) {
